# Sample code: Run object detection on image and print the results

import tfsdk
import os
options = tfsdk.ConfigurationOptions()
# Can set configuration options here
# ex:
# options.smallest_face_height = 40
# options.fd_mode = tfsdk.FACEDETECTIONMODE.VERSATILE
# options.fd_filter = tfsdk.FACEDETECTIONFILTER.BALANCED
# options.fr_model = tfsdk.FACIALRECOGNITIONMODEL.TFV5
# Note, if you do use TFV5, you will need to run the download script in /download_models to obtain the model file

# Use the accurate object detector
options.obj_model = tfsdk.OBJECTDETECTIONMODEL.ACCURATE 

sdk = tfsdk.SDK(options)

# TODO: export your license token as TRUEFACE_TOKEN environment variable
is_valid = sdk.set_license(os.environ['TRUEFACE_TOKEN'])
if (is_valid == False):
	print("Invalid License Provided")
	print("Be sure to export your license token as TRUEFACE_TOKEN")
	quit()

# Load the input image of a person on a bike
res = sdk.set_image("../images/person_on_bike.jpg")
if (res != tfsdk.ERRORCODE.NO_ERROR):
	print("Unable to set image 1")
	quit()

# Run object detection
bounding_boxes = sdk.detect_objects()
if (len(bounding_boxes) == 0) :
	print("Unable to find any objects in image")
	quit()


for bounding_box in bounding_boxes:
	# Get the bounding box label as a string
	label_string = sdk.get_object_label_string(bounding_box.label)


	print("Detected:", label_string, "with probability:", bounding_box.probability)
	print("Top left (x,y):", bounding_box.top_left.x, bounding_box.top_left.y, "width:", bounding_box.width, "height:", bounding_box.height)
	print()


